import { backendUrl } from "$lib/constants.js";
import { state, testMode } from "$lib/state.js";

const mockApi = {
    '/clusters': {
        'TestCluster': {
            clientId: 'TestClient',
            brokers: ['testbroker.com:5000'],
            sasl: {
                mechanism: 'SCRAM-SHA-512',
                username: 'testuser',
                password: 'XXXXXXXXXXXXXXXXXXXXXX'
            }
        }
    },
    '/topics/TestCluster': ['NewReleases']
}

/**
 * Returns the JSON response from the given path, or undefined if an error occurred
 * Sets `state.error` if something goes wrong.
 * @param path
 * @returns {Promise<any|undefined>}
 */
export const apiFetch = async path => {
    if (testMode) {
        return mockApi[path]
    }
    let response
    try {
        response = await fetch(`${backendUrl}${path}`)
    } catch (e) {
        console.error(e)
        state.update(s => ({ ...s, error: 'Could not connect to the backend' }))
        return undefined
    }
    try {
        return response.json()
    } catch (e) {
        console.error(e)
        state.update(s => ({ ...s, error: 'Received non-JSON response from backend' }))
        return undefined
    }
}